restrictImageToViewport property
A boolean flag that indicates whether the image should be restricted to the viewport.
Implementation
final bool restrictImageToViewport;
A boolean flag that indicates whether the image should be restricted to the viewport.
final bool restrictImageToViewport;