cropRect abstract method

Future<Uint8List> cropRect(
  1. Image image,
  2. Rect cropRect, {
  3. required ImageByteFormat format,
})

Crops the image in a rectangular shape.

image The image to be cropped. cropRect The rectangle specifying the crop area. format The format in which the cropped image should be returned.

Returns a Uint8List containing the cropped image in the specified format.

Implementation

Future<Uint8List> cropRect(ui.Image image, Rect cropRect, {
  required ui.ImageByteFormat format,
});