cropOval abstract method
Crops the image in an oval shape.
image The image to be cropped.
cropRect The rectangle specifying the crop area (used to determine the oval's bounding box).
format The format in which the cropped image should be returned.
Returns a Uint8List containing the cropped image in the specified format.
Implementation
Future<Uint8List> cropOval(ui.Image image, Rect cropRect, {
required ui.ImageByteFormat format,
});